==> nextcloud-26.0.13.zip: nextcloud/apps/circles/l10n/sk.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Tímy",
    "You deleted {circle}" : "Vymazali ste {circle}",
    "{author} deleted {circle}" : "{author} zmazal {circle}",
    "You joined {circle}" : "Pripojili ste sa ku kruhu {circle}",
    "{member} joined {circle}" : "{member} sa pripojil o kruhu {circle}",
    "You accepted the invitation to join {circle}" : "Prijali ste pozvanie k pripojeniu k {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} prijal(a) pozvanie k pripojeniu k {circle}",
    "You added {member} as member to {circle}" : "Pridali ste {member} do {circle}",
    "You have been added as member to {circle} by {author}" : "{author} vás pridal(a) do {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} pridal(a) {member} do {circlel}",
    "You added {external} to {circle}" : "Pridali ste {external} do {circle}",
    "{external} has been added to {circle} by {author}" : "{author} pridal(a) {external} do {circle}",
    "You accepted {member}'s request to join {circle}" : "Prijali ste požiadavku od {member} na pripojenie k {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Vaša žiadosť o pripojenie do kruhu {circle} bola prijatá používateľom {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} prijal(a) požiadavku {member} na pripojenie k {circle}",
    "You left {circle}" : "Opustili ste kruh {circle}",
    "{member} left {circle}" : "Používateľ {member} odišiel z kruhu {circle}",
    "You declined the invitation to join {circle}" : "Odmietli ste pozvánku pre pripojenie ku kruhu {circle}",
    "{member} declined an invitation to join {circle}" : "Používateľ {member} odmietol pozvánku pre pripojenie sa ku kruhu {circle}",
    "You cancelled your request to join {circle}" : "Zrušili ste vašu požiadavku o pripojenie k {circle}",
    "You removed {member} from {circle}" : "Odstranili ste {member} z {circle}",
    "You have been removed from {circle} by {author}" : "{author} vás odstránil(a) z {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} odstránil(a) {member} z {circle}",
    "You removed {external} from {circle}" : "Odstránili ste {external} z {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} odstránil(a) {external} z {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Zrušili ste pozvanie {member} na pripojenie k {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} zrušil(a) vašu pozvánku na pripojenie k {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} zrušil(a) pozvánku {member} na pripojenie k {circle}",
    "You dismissed {member}'s request to join {circle}" : "Odmietli ste požiadavku {member} na pripojenie k {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} odmietol(a) vašu požiadavku na pripojenie k {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} odmietol požiadavku {member} na pripojenie k {circle}",
    "You invited {member} to join {circle}" : "Pozvali ste {member} na pripojenie k {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vás pozval(a) k pripojeniu k {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} pozval(a) {member} k pripojeniu k {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Zmenili ste úroveň {member} v {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} zmenil(a) vašu úroveň v {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} zmenil(a) úroveň {member} v {circle} na %1$s",
    "You sent a request to join {circle}" : "Odoslali ste požiadavku na pripojenie k {circle}",
    "{member} sent a request to join {circle}" : "{member} odoslal(a) požiadavku na pripojenie k {circle}",
    "You are the new owner of {circle}" : "Ste novým vlastníkom {circle}",
    "{member} is the new owner of {circle}" : "{member} je novým vlastníkom {circle}",
    "Shared to Circles" : "Zdieľané v kruhoch",
    "Single" : "Slobodný",
    "Personal" : "Osobný",
    "System" : "Systém",
    "Visible" : "Viditeľné",
    "Open" : "Otvoriť",
    "Invite" : "Pozvať",
    "Friends" : "Priatelia",
    "Password protected" : "Chránené heslom",
    "No Owner" : "Žiadny vlastník",
    "Hidden" : "Skryté",
    "Backend" : "Backend",
    "Local" : "Lokálny",
    "Root" : "Koreň",
    "Federated" : "Združený",
    "Mount point" : "Prípojný bod",
    "Nextcloud Account" : "Účet Nextcloud",
    "Nextcloud Group" : "Skupina Nextcloud",
    "Email address" : "E-mailová adresa",
    "Contact" : "Kontakt",
    "Circle" : "Kruh",
    "Nextcloud App" : "Aplikácia Nextcloud",
    "Member" : "Člen",
    "Moderator" : "Moderátor",
    "Admin" : "Administrátor",
    "Owner" : "Vlastník",
    "%s shared »%s« with you." : "%s vám sprístupnil »%s«",
    "%s shared »%s« with \"%s\"." : "%s zdieľané »%s« s \"%s\".",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s s vami zdieľa »%2$s«.\nUž ste mali dostať e-mail s odkazom na prístup k ním.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s s vami zdieľa »%2$s«. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access »%1$s« shared to you by %2$s" : "Heslo pre prístup k »%1$s« Vám sprístupnil %2$s",
    "Password to access »%s«" : "Heslo pre prístup k »%s«",
    "It is protected with the following password:" : "Je chránené nasledovným heslom:",
    "%1$s via %2$s" : "%1$s cez %2$s",
    "Click the button below to open it." : "Stlačte tlačidlo nižšie pre otvorenie.",
    "Open »%s«" : "Otvoriť »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s s vami zdieľa niekoľko súborov.\nUž ste mali dostať e-mail s odkazom na prístup k ním.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s s vami zdieľa niekoľko súborov. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access files shared to you by %1$s" : "Heslo pre prístup k súborom, ktoré s vami zdieľa %1$s",
    "Password to access files" : "Heslo pre prístup k súborom",
    "%s shared multiple files with \"%s\"." : "%s zdieľa viacero súborov s \"%s\".",
    "%s shared multiple files with you." : "%s s vami zdieľa súbory.",
    "Boot up" : "Štart",
    "Fresh installation status" : "Stav čistej inštalácie",
    "Building Local Database" : "Vytváram Lokálnu Databázu",
    "Testing Basic Circle Creation" : "Testujem základné pridávanie Kruhov",
    "Adding local users and moderators" : "Pridávam lokálnych užívateľov a moderátorov",
    "Files" : "Súbory",
    "This feature is not available for personal circles" : "Táto funkcia nie je k dispozícii pre osobné kruhy",
    "This member is not a moderator" : "Tento člen nie je moderátor",
    "Insufficient privileges" : "Nedostatočné oprávnenia",
    "This member does not exist" : "Tento používateľ neexistuje",
    "Level cannot be changed for this type of member" : "Pre tento typ člena, úroveň nemôže byť zmenená.",
    "You are already a member of this circle" : "Už ste členom tohto kruhu",
    "You have been blocked from this circle" : "Boli ste zablokovaný z tohto kruhu",
    "The account is already a member of this circle" : "Tento užívateľ už je členom kruhu",
    "The account has already been invited into this circle" : "Užívateľ už bol pozvaný do tohto kruhu",
    "You are now a member of the Circle \"%2$s\"" : "Teraz ste členom kruhu \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Do kruhu \"%2$s\" vás pozval(a) %1$s",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "Požiadavku, stať sa členom kruhu \"%2$s\", zaslal(a) %1$s",
    "Accept" : "Prijať",
    "Refuse" : "Odmietnuť",
    "Leave the circle" : "Opustiť kruh",
    "%s" : "%s",
    "%s owned by %s" : "%s vlastnené %s",
    "%s shared a file with \"%s\"." : "%s zozdieľal súbor s \"%s\".",
    "%s shared a file with you." : "%s vám nazdieľal súbor.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s s vami zdieľa nejaký obsah. Už ste mali dostať e-mail so samostatným odkazom na prístup k nemu.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s s vami zdieľa nejaký obsah. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access content shared with you by %1$s" : "Heslo pre prístup k obsahu, ktorý s vami zdieľa %1$s",
    "Password to access content" : "Heslo pre prístup k obsahu",
    "Bring cloud-users closer together." : "Zblížte používateľov cloudu.",
    "No files in here" : "Nie sú tu žiadne súbory",
    "No entries found in this folder" : "V tomto priečinku sa nič nenašlo",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "Circles" : "Kruhy",
    "Circles' files" : "Súbory kruhu",
    "Select circles to filter by" : "Vyberte kruhy, ktoré chcete filtrovať",
    "No circles found" : "Nenašli sa žiadne kruhy",
    "Please select circles to filter by" : "Vyberte kruhy, ktoré chcete filtrovať",
    "No files found for the selected circles" : "Pre vybrané kruhy neboli nájdené žiadne súbory",
    "You created the circle {circle}" : "Vytvorili ste kruh {circle}",
    "{author} created the circle {circle}" : "{author} vytvoril kruh {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Pri udalostiach odohrávajúcich sa v <strong>okrhu</strong>, ktorého ste členom/členkou",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Dôležité udalosti v <strong>kruhu</strong>, ktorý moderujete",
    "On global events happening in any <strong>Circle</strong>" : "Pri globálnych udalostiach, ktoré sa odohrávajú v ktoromkoľvek <strong>kruhu</strong>",
    "Join Request" : "Žiadosť o pripojenie",
    "Password Protected" : "Chránené heslom",
    "Circle Invite" : "Pozvať do kruhu",
    "Email Address" : "E-mailová adresa",
    "Initialisation Nextcloud" : "Inicializácia Nextcloudu",
    "Initialisation Circles App" : "Inicializácia Aplikácie Kruhy",
    "Circle not found" : "Kruh sa nenašiel",
    "Circle not found " : "Kruh nebol nájdený ",
    "This account is already a member of the circle" : "Tento užívateľ už je členom kruhu",
    "Federated link not found" : "Združené prepojenie sa nenašlo",
    "The circle is not federated" : "Kruh nie je združený",
    "You cannot join this circle" : "Nemôžete sa pripojiť k tomuto kruhu",
    "This member is the owner of the circle" : "Tento člen je vlastník kruhu",
    "%s (Circle owned by %s)" : "%s (Kruh vlastnený %s)",
    "Personal Circle" : "Osobný kruh",
    "You need a specify a type of circle" : "Musíte špecifikovať typ kruhu",
    "A circle with that name exists" : "Kruh s týmto názvom existuje",
    "This member is not the owner of the circle" : "Tento člen nie je vlastník kruhu",
    "This member is not an admin of the circle" : "Tento člen nie je správcom kruhu",
    "Group contains too many members" : "Skupina obsahuje priveľa členov",
    "This group does not exist" : "Táto skupina neexistuje",
    "This group is already linked to the circle" : "Táto skupina je už s kruhom prepojená",
    "You cannot edit level in a personal circle" : "Úroveň osobného kruhu sa nedá upraviť",
    "Group cannot be set as owner of a circle" : "Skupina nemôže byť nastavená ako vlastník kruhu",
    "now" : "teraz",
    "This account does not exist" : "Tento účet neexistuje",
    "Email format is not valid" : "Nesprávny formát e-mailu",
    "This contact is not available" : "Tento kontakt je nedostupný",
    "You have no permission to create a new circle" : "Nemáte oprávnenia pre vytváranie nových kruhov",
    "This item is already shared with this circle" : "Táto položka je už zdieľaná s týmto kruhom",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Kruhy umožňujú vašim užívateľom vytvárať ich vlastné skupiny užívateľov/kolegov/priateľov.\nTieto skupiny užívateľov (alebo \"kruhov\") môžu buť potom používané akoukoľvek inou aplikáciou pre potreby zdieľania."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-29.0.12.zip: nextcloud/apps/circles/l10n/sk.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Tímy",
    "You created the team {circle}" : "Vytvorili ste tím {circle}",
    "{author} created the team {circle}" : "{author} vytvoril tím {circle}",
    "You deleted {circle}" : "Vymazali ste {circle}",
    "{author} deleted {circle}" : "{author} zmazal {circle}",
    "You made {member} join {circle}" : "Užívateľa {member} ste pripojili k {circle}",
    "{author} made {member} join {circle}" : "{author} pripojil užívateľa {member} k {circle}",
    "You added team {member} as member to {circle}" : "Pridali ste tím {member} ako člena k {circle}",
    "{author} added team {member} as member to {circle}" : "{author} pridal/a tím {member} ako člena do {circle}",
    "You made {member} leave {circle}" : "Užívateľa {member} ste odpojili od {circle}",
    "{author} made {member} leave {circle}" : "{author} odpojil užívateľa {member} od {circle}",
    "You removed {member} from {circle}" : "Odstranili ste {member} z {circle}",
    "{author} removed {member} from {circle}" : "{author} odstránil/a {member} z {circle}",
    "You joined {circle}" : "Pripojili ste sa ku kruhu {circle}",
    "{member} joined {circle}" : "{member} sa pripojil o kruhu {circle}",
    "You accepted the invitation to join {circle}" : "Prijali ste pozvanie k pripojeniu k {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} prijal(a) pozvanie k pripojeniu k {circle}",
    "You added {member} as member to {circle}" : "Pridali ste {member} do {circle}",
    "You have been added as member to {circle} by {author}" : "{author} vás pridal(a) do {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} pridal(a) {member} do {circlel}",
    "You added {external} to {circle}" : "Pridali ste {external} do {circle}",
    "{external} has been added to {circle} by {author}" : "{author} pridal(a) {external} do {circle}",
    "You accepted {member}'s request to join {circle}" : "Prijali ste požiadavku od {member} na pripojenie k {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Vaša žiadosť o pripojenie do kruhu {circle} bola prijatá používateľom {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} prijal(a) požiadavku {member} na pripojenie k {circle}",
    "You left {circle}" : "Opustili ste kruh {circle}",
    "{member} left {circle}" : "Používateľ {member} odišiel z kruhu {circle}",
    "You declined the invitation to join {circle}" : "Odmietli ste pozvánku pre pripojenie ku kruhu {circle}",
    "{member} declined an invitation to join {circle}" : "Používateľ {member} odmietol pozvánku pre pripojenie sa ku kruhu {circle}",
    "You cancelled your request to join {circle}" : "Zrušili ste vašu požiadavku o pripojenie k {circle}",
    "{member} cancelled a request to join {circle}" : "{member} zrušil žiadosť o pripojeni k {circle}",
    "You have been removed from {circle} by {author}" : "{author} vás odstránil(a) z {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} odstránil(a) {member} z {circle}",
    "You removed {external} from {circle}" : "Odstránili ste {external} z {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} odstránil(a) {external} z {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Zrušili ste pozvanie {member} na pripojenie k {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} zrušil(a) vašu pozvánku na pripojenie k {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} zrušil(a) pozvánku {member} na pripojenie k {circle}",
    "You dismissed {member}'s request to join {circle}" : "Odmietli ste požiadavku {member} na pripojenie k {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} odmietol(a) vašu požiadavku na pripojenie k {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} odmietol požiadavku {member} na pripojenie k {circle}",
    "You invited {member} to join {circle}" : "Pozvali ste {member} na pripojenie k {circle}",
    "You have been invited to join {circle} by {author}" : "{author} vás pozval(a) k pripojeniu k {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} pozval(a) {member} k pripojeniu k {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Zmenili ste úroveň {member} v {circle} na %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} zmenil(a) vašu úroveň v {circle} na %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} zmenil(a) úroveň {member} v {circle} na %1$s",
    "You sent a request to join {circle}" : "Odoslali ste požiadavku na pripojenie k {circle}",
    "{member} sent a request to join {circle}" : "{member} odoslal(a) požiadavku na pripojenie k {circle}",
    "You are the new owner of {circle}" : "Ste novým vlastníkom {circle}",
    "{member} is the new owner of {circle}" : "{member} je novým vlastníkom {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Pri udalostiach odohrávajúcich sa v <strong>tíme</strong>, ktorého ste členom/členkou",
    "Any important event in a <strong>team</strong> you are moderating" : "Dôležité udalosti v <strong>tíme</strong>, ktorý moderujete",
    "On global events happening in any <strong>team</strong>" : "Pri globálnych udalostiach, ktoré sa odohrávajú v ktoromkoľvek <strong>tíme</strong>",
    "Shared to Circles" : "Zdieľané v kruhoch",
    "Single" : "Slobodný",
    "Personal" : "Osobný",
    "System" : "Systém",
    "Visible" : "Viditeľné",
    "Open" : "Otvoriť",
    "Invite" : "Pozvať",
    "Join request" : "Žiadosť o pripojenie",
    "Friends" : "Priatelia",
    "Password protected" : "Chránené heslom",
    "No Owner" : "Žiadny vlastník",
    "Hidden" : "Skryté",
    "Backend" : "Backend",
    "Local" : "Lokálny",
    "Root" : "Koreň",
    "Team invite" : "Pozvánka do tímu",
    "Federated" : "Združený",
    "Mount point" : "Prípojný bod",
    "Nextcloud Account" : "Účet Nextcloud",
    "Nextcloud Group" : "Skupina Nextcloud",
    "Email address" : "E-mailová adresa",
    "Contact" : "Kontakt",
    "Circle" : "Kruh",
    "Nextcloud App" : "Aplikácia Nextcloud",
    "Member" : "Člen",
    "Moderator" : "Moderátor",
    "Admin" : "Administrátor",
    "Owner" : "Vlastník",
    "%s shared »%s« with you." : "%s vám sprístupnil »%s«",
    "%s shared »%s« with \"%s\"." : "%s zdieľané »%s« s \"%s\".",
    "%s on %s" : "%s na %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s s vami zdieľa »%2$s«.\nUž ste mali dostať e-mail s odkazom na prístup k ním.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s s vami zdieľa »%2$s«. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access »%1$s« shared to you by %2$s" : "Heslo pre prístup k »%1$s« Vám sprístupnil %2$s",
    "Password to access »%s«" : "Heslo pre prístup k »%s«",
    "It is protected with the following password:" : "Je chránené nasledovným heslom:",
    "%1$s via %2$s" : "%1$s cez %2$s",
    "Click the button below to open it." : "Stlačte tlačidlo nižšie pre otvorenie.",
    "Open »%s«" : "Otvoriť »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s s vami zdieľa niekoľko súborov.\nUž ste mali dostať e-mail s odkazom na prístup k ním.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s s vami zdieľa niekoľko súborov. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access files shared to you by %1$s" : "Heslo pre prístup k súborom, ktoré s vami zdieľa %1$s",
    "Password to access files" : "Heslo pre prístup k súborom",
    "%s shared multiple files with \"%s\"." : "%s zdieľa viacero súborov s \"%s\".",
    "%s shared multiple files with you." : "%s s vami zdieľa súbory.",
    "Boot up" : "Štart",
    "Nextcloud Initialization" : "Inicializácia Nextcloudu",
    "Circles App Initialization" : "Inicializácia Aplikácie Kruhy",
    "Fresh installation status" : "Stav čistej inštalácie",
    "Building Local Database" : "Vytváram Lokálnu Databázu",
    "Testing Basic Circle Creation" : "Testujem základné pridávanie Kruhov",
    "Adding local users and moderators" : "Pridávam lokálnych užívateľov a moderátorov",
    "Show all teams" : "Zobraziť všetky tímy",
    "Create a new team" : "Vytvoriť nový tím",
    "Files" : "Súbory",
    "This feature is not available for personal circles" : "Táto funkcia nie je k dispozícii pre osobné kruhy",
    "The team is not federated" : "Tím nie je združený",
    "You cannot join this team" : "Nemôžete sa pripojiť k tomuto tímu",
    "This member is not a moderator" : "Tento člen nie je moderátor",
    "Insufficient privileges" : "Nedostatočné oprávnenia",
    "This member does not exist" : "Tento používateľ neexistuje",
    "This member is the owner of the team" : "Tento člen je vlastníkom tímu",
    "Level cannot be changed for this type of member" : "Pre tento typ člena, úroveň nemôže byť zmenená.",
    "You are already a member of this circle" : "Už ste členom tohto kruhu",
    "You have been blocked from this circle" : "Boli ste zablokovaný z tohto kruhu",
    "The account is already a member of this circle" : "Tento užívateľ už je členom kruhu",
    "The account has already been invited into this circle" : "Užívateľ už bol pozvaný do tohto kruhu",
    "%s (Team owned by %s)" : "%s (Tím vlastnený %s)",
    "You are now a member of the Team \"%2$s\"" : "Teraz ste členom tímu „%2$s“",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Boli ste pozvaní používateľom %1$sdo tímu „%2$s“",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s poslal žiadosť o členstvo v tíme „%2$s“",
    "Accept" : "Prijať",
    "Refuse" : "Odmietnuť",
    "Leave the team" : "Opustiť tím",
    "%s" : "%s",
    "Personal team" : "Osobný tím",
    "%s owned by %s" : "%s vlastnené %s",
    "You have no permission to create a new team" : "Nemáte oprávnenia pre vytváranie nového tímu",
    "%s shared a file with \"%s\"." : "%s zozdieľal súbor s \"%s\".",
    "%s shared a file with you." : "%s vám nazdieľal súbor.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s s vami zdieľa nejaký obsah. Už ste mali dostať e-mail so samostatným odkazom na prístup k nemu.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s s vami zdieľa nejaký obsah. Už ste mali dostať e-mail s odkazom na prístup k ním.",
    "Password to access content shared with you by %1$s" : "Heslo pre prístup k obsahu, ktorý s vami zdieľa %1$s",
    "Password to access content" : "Heslo pre prístup k obsahu",
    "This item is already shared with this team" : "Táto položka je už zdieľaná s týmto tímom",
    "Bring cloud-users closer together." : "Zblížte používateľov cloudu.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Tímy umožňujú vašim užívateľom vytvárať ich vlastné skupiny užívateľov/kolegov/priateľov.\nTieto skupiny užívateľov môžu byť potom používané akoukoľvek inou aplikáciou pre potreby zdieľania.",
    "No files in here" : "Nie sú tu žiadne súbory",
    "No entries found in this folder" : "V tomto priečinku sa nič nenašlo",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "Teams' files" : "Súbory tímov",
    "Select team to filter by" : "Vybrať tím pre filtrovanie",
    "No teams found" : "Žiadne tímy sa nenašli",
    "Please select teams to filter by" : "Prosím, vyberte tímy pre filtrovanie",
    "No files found for the selected teams" : "Pre vybrané tímy neboli nájdené žiadne súbory",
    "{author} added team {member} has been added as member to {circle}" : "{author} pridal tím {member} ako člena k {circle}",
    "You are now a member of the Circle \"%2$s\"" : "Teraz ste členom kruhu \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Do kruhu \"%2$s\" vás pozval(a) %1$s",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "Požiadavku, stať sa členom kruhu \"%2$s\", zaslal(a) %1$s",
    "Leave the circle" : "Opustiť kruh"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
